summaryrefslogtreecommitdiff
path: root/qa/qa/support/formatters/test_stats_formatter.rb
diff options
context:
space:
mode:
Diffstat (limited to 'qa/qa/support/formatters/test_stats_formatter.rb')
-rw-r--r--qa/qa/support/formatters/test_stats_formatter.rb7
1 files changed, 4 insertions, 3 deletions
diff --git a/qa/qa/support/formatters/test_stats_formatter.rb b/qa/qa/support/formatters/test_stats_formatter.rb
index 6f6291b5856..7678cb8406c 100644
--- a/qa/qa/support/formatters/test_stats_formatter.rb
+++ b/qa/qa/support/formatters/test_stats_formatter.rb
@@ -84,7 +84,8 @@ module QA
retry_attempts: example.metadata[:retry_attempts] || 0,
job_url: QA::Runtime::Env.ci_job_url,
pipeline_url: env('CI_PIPELINE_URL'),
- pipeline_id: env('CI_PIPELINE_ID')
+ pipeline_id: env('CI_PIPELINE_ID'),
+ testcase: example.metadata[:testcase]
}
}
rescue StandardError => e
@@ -124,11 +125,11 @@ module QA
@merge_request ||= (!!env('CI_MERGE_REQUEST_IID') || !!env('TOP_UPSTREAM_MERGE_REQUEST_IID')).to_s
end
# Test run type from staging, canary, preprod or production env
#
# @return [String, nil]
def run_type
- return unless %w[staging canary preprod production].include?(project_name)
+ return unless %w[staging staging-canary staging-ref canary preprod production].include?(project_name)
@run_type ||= begin
test_subset = if env('NO_ADMIN') == 'true'
@@ -124,11 +125,11 @@ module QA
end
- # Test run type from staging, canary, preprod or production env
+ # Test run type from staging (`gstg`, `gstg-cny`, `gstg-ref`), canary, preprod or production env
#
# @return [String, nil]